@@ -10,19 +10,29 @@ from NotionDump.utils import internal_var
 # Block内容解析
 class Block:
     # 初始化
-    def __init__(self, block_id, query_handle: NotionQuery, export_child_pages=False, parser_type=NotionDump.PARSER_TYPE_MD):
+    def __init__(
+            self,
+            block_id,
+            query_handle:
+            NotionQuery,
+            export_child_pages=False,
+            page_parser_type=NotionDump.PARSER_TYPE_MD,
+            db_parser_type=NotionDump.PARSER_TYPE_PLAIN
+    ):
         self.block_id = block_id.replace('-', '')
         self.query_handle = query_handle
         # 是否导出子页面
         self.export_child_page = export_child_pages
-        self.parser_type = parser_type
+        self.page_parser_type = page_parser_type
+        self.db_parser_type = db_parser_type
 
         # 构造解析器
         self.page_handle = Page(
             page_id=self.block_id,
             query_handle=self.query_handle,
             export_child_pages=self.export_child_page,
-            parser_type=self.parser_type
+            page_parser_type=self.page_parser_type,
+            db_parser_type=self.db_parser_type
         )
 
     # show_child_page
